@@ -1,6 +1,5 @@
 #pragma once
 
-#include "breezehelper.h"
 #include "breezestyle.h"
 #include <KConfigWatcher>
 #include <KSharedConfig>
@@ -26,12 +25,12 @@ class AppListener : public QObject
     friend class ToolsAreaManager;
 };
 
+//* signal manager for the tools area
 class ToolsAreaManager : public QObject
 {
     Q_OBJECT
 
 private:
-    Helper *_helper;
     QHash<const QMainWindow *, QVector<QPointer<QToolBar>>> _windows;
     KSharedConfigPtr _config;
     KConfigWatcher::Ptr _watcher;
@@ -47,7 +46,7 @@ protected:
     void configUpdated();
 
 public:
-    explicit ToolsAreaManager(Helper *helper, QObject *parent = nullptr);
+    explicit ToolsAreaManager();
     ~ToolsAreaManager();
 
     bool eventFilter(QObject *watched, QEvent *event) override;
