@@ -25,13 +25,15 @@
 
 namespace Breeze
 {
+class AppEventFilter;
+
 class WindowManager : public QObject
 {
     Q_OBJECT
 
 public:
     //* constructor
-    explicit WindowManager(QObject *);
+    explicit WindowManager();
 
     //* initialize
     /** read relevant options from config */
@@ -262,15 +264,16 @@ private:
     //* true if drag is locked
     bool _locked = false;
 
-    //* true if the event we are intercepting passed trough a QQuickWidget.
+    //* true if the event we are intercepting passed through a QQuickWidget.
     /**In this case we shouldn't start a drag, because if it was to start, we would have done it in the event filter of a qquickwidget.
      * Event handlers don't accept input events, but they do block QQuickItems to receive the event, so the event may have been
      * managed by an handler and not blocked by the root qml item.
      **/
     bool _eventInQQuickWidget = false;
 
+    // lifetime: parented to this
     //* application event filter
-    QObject *_appEventFilter = nullptr;
+    AppEventFilter *_appEventFilter = nullptr;
 
     //* allow access of all private members to the app event filter
     friend class AppEventFilter;
